@@ -62,12 +62,12 @@ pub(crate) fn cmd_file_chmod(
     };
 
     let mut workspace_command = command.workspace_helper(ui)?;
-    let commit = workspace_command.resolve_single_rev(&args.revision)?;
+    let commit = workspace_command.resolve_single_rev(ui, &args.revision)?;
     workspace_command.check_rewritable([commit.id()])?;
     let tree = commit.tree()?;
     // TODO: No need to add special case for empty paths when switching to
     // parse_union_filesets(). paths = [] should be "none()" if supported.
-    let fileset_expression = workspace_command.parse_file_patterns(&args.paths)?;
+    let fileset_expression = workspace_command.parse_file_patterns(ui, &args.paths)?;
     let matcher = fileset_expression.to_matcher();
     print_unmatched_explicit_paths(ui, &workspace_command, &fileset_expression, [&tree])?;
 
@@ -108,7 +108,7 @@ pub(crate) fn cmd_file_chmod(
     }
 
     let new_tree_id = tree_builder.write_tree(store)?;
-    tx.mut_repo()
+    tx.repo_mut()
         .rewrite_commit(command.settings(), &commit)
         .set_tree_id(new_tree_id)
         .write()?;
