@@ -16,7 +16,7 @@ mod abandon;
 mod backout;
 #[cfg(feature = "bench")]
 mod bench;
-mod branch;
+mod bookmark;
 mod checkout;
 mod commit;
 mod config;
@@ -26,6 +26,7 @@ mod diff;
 mod diffedit;
 mod duplicate;
 mod edit;
+mod evolog;
 mod file;
 mod fix;
 mod git;
@@ -36,7 +37,6 @@ mod merge;
 mod r#move;
 mod new;
 mod next;
-mod obslog;
 mod operation;
 mod parallelize;
 mod prev;
@@ -77,8 +77,10 @@ enum Command {
     #[command(subcommand)]
     Bench(bench::BenchCommand),
     #[command(subcommand)]
-    Branch(branch::BranchCommand),
-    // TODO: Delete `cat` in jj 0.25+
+    Bookmark(bookmark::BookmarkCommand),
+    // TODO: Remove in jj 0.28+
+    #[command(subcommand, hide = true)]
+    Branch(bookmark::BookmarkCommand),
     #[command(alias = "print", hide = true)]
     Cat(file::show::FileShowArgs),
     #[command(hide = true)]
@@ -96,6 +98,8 @@ enum Command {
     Diffedit(diffedit::DiffeditArgs),
     Duplicate(duplicate::DuplicateArgs),
     Edit(edit::EditArgs),
+    #[command(alias = "obslog", visible_alias = "evolution-log")]
+    Evolog(evolog::EvologArgs),
     #[command(subcommand)]
     File(file::FileCommand),
     /// List files in a revision (DEPRECATED use `jj file list`)
@@ -108,7 +112,7 @@ enum Command {
     Init(init::InitArgs),
     Interdiff(interdiff::InterdiffArgs),
     Log(log::LogArgs),
-    /// Merge work from multiple branches (DEPRECATED, use `jj new`)
+    /// Merge work from multiple bookmarks (DEPRECATED, use `jj new`)
     ///
     /// Unlike most other VCSs, `jj merge` does not implicitly include the
     /// working copy revision's parent as one of the parents of the merge;
@@ -123,7 +127,6 @@ enum Command {
     Move(r#move::MoveArgs),
     New(new::NewArgs),
     Next(next::NextArgs),
-    Obslog(obslog::ObslogArgs),
     #[command(subcommand)]
     #[command(visible_alias = "op")]
     Operation(operation::OperationCommand),
@@ -153,6 +156,8 @@ enum Command {
     Util(util::UtilCommand),
     /// Undo an operation (shortcut for `jj op undo`)
     Undo(operation::undo::OperationUndoArgs),
+    // TODO: Delete `unsquash` in jj 0.28+
+    #[command(hide = true)]
     Unsquash(unsquash::UnsquashArgs),
     // TODO: Delete `untrack` in jj 0.27+
     #[command(hide = true)]
@@ -181,7 +186,11 @@ pub fn run_command(ui: &mut Ui, command_helper: &CommandHelper) -> Result<(), Co
         Command::Backout(args) => backout::cmd_backout(ui, command_helper, args),
         #[cfg(feature = "bench")]
         Command::Bench(args) => bench::cmd_bench(ui, command_helper, args),
-        Command::Branch(args) => branch::cmd_branch(ui, command_helper, args),
+        Command::Bookmark(args) => bookmark::cmd_bookmark(ui, command_helper, args),
+        Command::Branch(args) => {
+            let cmd = renamed_cmd("branch", "bookmark", bookmark::cmd_bookmark);
+            cmd(ui, command_helper, args)
+        }
         Command::Cat(args) => {
             let cmd = renamed_cmd("cat", "file show", file::show::cmd_file_show);
             cmd(ui, command_helper, args)
@@ -213,7 +222,7 @@ pub fn run_command(ui: &mut Ui, command_helper: &CommandHelper) -> Result<(), Co
         Command::Move(args) => r#move::cmd_move(ui, command_helper, args),
         Command::New(args) => new::cmd_new(ui, command_helper, args),
         Command::Next(args) => next::cmd_next(ui, command_helper, args),
-        Command::Obslog(args) => obslog::cmd_obslog(ui, command_helper, args),
+        Command::Evolog(args) => evolog::cmd_evolog(ui, command_helper, args),
         Command::Operation(args) => operation::cmd_operation(ui, command_helper, args),
         Command::Parallelize(args) => parallelize::cmd_parallelize(ui, command_helper, args),
         Command::Prev(args) => prev::cmd_prev(ui, command_helper, args),
@@ -242,7 +251,7 @@ pub fn run_command(ui: &mut Ui, command_helper: &CommandHelper) -> Result<(), Co
 }
 
 /// Wraps deprecated command of `old_name` which has been renamed to `new_name`.
-fn renamed_cmd<Args>(
+pub(crate) fn renamed_cmd<Args>(
     old_name: &'static str,
     new_name: &'static str,
     cmd: impl Fn(&mut Ui, &CommandHelper, &Args) -> Result<(), CommandError>,
