@@ -13,14 +13,18 @@
 // limitations under the License.
 
 use std::io::Write as _;
-use std::{iter, slice};
+use std::iter;
+use std::slice;
 
 use itertools::Itertools as _;
 use jj_lib::op_walk;
 use jj_lib::operation::Operation;
 
-use crate::cli_util::{short_operation_hash, CommandHelper};
-use crate::command_error::{cli_error, user_error, CommandError};
+use crate::cli_util::short_operation_hash;
+use crate::cli_util::CommandHelper;
+use crate::command_error::cli_error;
+use crate::command_error::user_error;
+use crate::command_error::CommandError;
 use crate::ui::Ui;
 
 /// Abandon operation history
@@ -51,7 +55,7 @@ pub fn cmd_op_abandon(
     let repo_loader = workspace.repo_loader();
     let op_store = repo_loader.op_store();
     let op_heads_store = repo_loader.op_heads_store();
-    // It doesn't make sense to create concurrent operations that will be merged
+    // It doesn't make sense to create divergent operations that will be merged
     // with the current head.
     if command.global_args().at_operation.is_some() {
         return Err(cli_error("--at-op is not respected"));
@@ -125,7 +129,7 @@ pub fn cmd_op_abandon(
         op_heads_store.update_op_heads(slice::from_ref(old.id()), new_id);
     }
     // Remap the operation id of the current workspace. If there were any
-    // concurrent operations, user will need to re-abandon their ancestors.
+    // divergent operations, user will need to re-abandon their ancestors.
     if !command.global_args().ignore_working_copy {
         let mut locked_ws = workspace.start_working_copy_mutation()?;
         let old_op_id = locked_ws.locked_wc().old_operation_id();
