@@ -54,7 +54,13 @@ pub fn cmd_op_restore(
         tx.base_repo().view().store_view(),
         &args.what,
     );
-    tx.mut_repo().set_view(new_view);
+    tx.repo_mut().set_view(new_view);
+    if let Some(mut formatter) = ui.status_formatter() {
+        write!(formatter, "Restored to operation ")?;
+        let template = tx.base_workspace_helper().operation_summary_template();
+        template.format(&target_op, formatter.as_mut())?;
+        writeln!(formatter)?;
+    }
     tx.finish(ui, format!("restore to operation {}", target_op.id().hex()))?;
 
     Ok(())
