@@ -7,16 +7,17 @@ use indoc::indoc;
 use itertools::Itertools;
 use jj_lib::backend::CommitId;
 use jj_lib::commit::Commit;
-use jj_lib::repo::ReadonlyRepo;
 use jj_lib::settings::UserSettings;
 use thiserror::Error;
 
 use crate::cli_util::edit_temp_file;
 use crate::cli_util::short_commit_hash;
+use crate::cli_util::WorkspaceCommandHelper;
 use crate::cli_util::WorkspaceCommandTransaction;
 use crate::command_error::CommandError;
 use crate::formatter::PlainTextFormatter;
 use crate::text_util;
+use crate::ui::Ui;
 
 /// Cleanup a description by normalizing line endings, and removing leading and
 /// trailing blank lines.
@@ -33,7 +34,7 @@ where
 }
 
 pub fn edit_description(
-    repo: &ReadonlyRepo,
+    workspace_command: &WorkspaceCommandHelper,
     description: &str,
     settings: &UserSettings,
 ) -> Result<String, CommandError> {
@@ -47,7 +48,7 @@ JJ: Lines starting with "JJ: " (like this one) will be removed.
     let description = edit_temp_file(
         "description",
         ".jjdescription",
-        repo.repo_path(),
+        workspace_command.repo_path(),
         &description,
         settings,
     )?;
@@ -57,8 +58,8 @@ JJ: Lines starting with "JJ: " (like this one) will be removed.
 
 /// Edits the descriptions of the given commits in a single editor session.
 pub fn edit_multiple_descriptions(
-    tx: &mut WorkspaceCommandTransaction,
-    repo: &ReadonlyRepo,
+    ui: &Ui,
+    tx: &WorkspaceCommandTransaction,
     commits: &[(&CommitId, Commit)],
     settings: &UserSettings,
 ) -> Result<ParsedBulkEditMessage<CommitId>, CommandError> {
@@ -78,7 +79,7 @@ pub fn edit_multiple_descriptions(
         bulk_message.push_str(&commit_hash);
         bulk_message.push_str(" -------\n");
         commits_map.insert(commit_hash, *commit_id);
-        let template = description_template(tx, "", temp_commit)?;
+        let template = description_template(ui, tx, "", temp_commit)?;
         bulk_message.push_str(&template);
         bulk_message.push('\n');
     }
@@ -87,7 +88,7 @@ pub fn edit_multiple_descriptions(
     let bulk_message = edit_temp_file(
         "description",
         ".jjdescription",
-        repo.repo_path(),
+        tx.base_workspace_helper().repo_path(),
         &bulk_message,
         settings,
     )?;
@@ -178,7 +179,7 @@ where
 /// then that one is used. Otherwise we concatenate the messages and ask the
 /// user to edit the result in their editor.
 pub fn combine_messages(
-    repo: &ReadonlyRepo,
+    workspace_command: &WorkspaceCommandHelper,
     sources: &[&Commit],
     destination: &Commit,
     settings: &UserSettings,
@@ -208,7 +209,7 @@ pub fn combine_messages(
         combined.push_str("\nJJ: Description from source commit:\n");
         combined.push_str(commit.description());
     }
-    edit_description(repo, &combined, settings)
+    edit_description(workspace_command, &combined, settings)
 }
 
 /// Create a description from a list of paragraphs.
@@ -226,6 +227,7 @@ pub fn join_message_paragraphs(paragraphs: &[String]) -> String {
 
 /// Renders commit description template, which will be edited by user.
 pub fn description_template(
+    ui: &Ui,
     tx: &WorkspaceCommandTransaction,
     intro: &str,
     commit: &Commit,
@@ -239,7 +241,7 @@ pub fn description_template(
     // Named as "draft" because the output can contain "JJ: " comment lines.
     let template_key = "templates.draft_commit_description";
     let template_text = tx.settings().config().get_string(template_key)?;
-    let template = tx.parse_commit_template(&template_text)?;
+    let template = tx.parse_commit_template(ui, &template_text)?;
 
     let mut output = Vec::new();
     if !intro.is_empty() {
