@@ -16,16 +16,21 @@
 
 pub mod cleanup_guard;
 pub mod cli_util;
+pub mod command_error;
 pub mod commands;
 pub mod commit_templater;
 pub mod config;
 pub mod description_util;
 pub mod diff_util;
 pub mod formatter;
+pub mod generic_templater;
+pub mod git_util;
 pub mod graphlog;
 pub mod merge_tools;
+pub mod movement_util;
 pub mod operation_templater;
 mod progress;
+pub mod revset_util;
 pub mod template_builder;
 pub mod template_parser;
 pub mod templater;
