@@ -10,10 +10,10 @@ fn test_no_forgotten_test_files() {
 
 mod test_abandon_command;
 mod test_acls;
-mod test_advance_branches;
+mod test_advance_bookmarks;
 mod test_alias;
 mod test_backout_command;
-mod test_branch_command;
+mod test_bookmark_command;
 mod test_builtin_aliases;
 mod test_checkout;
 mod test_commit_command;
@@ -27,9 +27,10 @@ mod test_diff_command;
 mod test_diffedit_command;
 mod test_duplicate_command;
 mod test_edit_command;
+mod test_evolog_command;
 mod test_file_chmod_command;
 mod test_file_print_command;
-mod test_file_untrack_command;
+mod test_file_track_untrack_commands;
 mod test_fix_command;
 mod test_generate_md_cli_help;
 mod test_git_clone;
@@ -50,7 +51,6 @@ mod test_log_command;
 mod test_move_command;
 mod test_new_command;
 mod test_next_prev_commands;
-mod test_obslog_command;
 mod test_operations;
 mod test_parallelize_command;
 mod test_rebase_command;
