@@ -65,7 +65,7 @@ fn test_config_no_tools() {
     let stderr = test_env.jj_cmd_failure(&repo_path, &["fix"]);
     insta::assert_snapshot!(stderr, @r###"
     Config error: At least one entry of `fix.tools` or `fix.tool-command` is required.
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
 
     let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "file", "-r", "@"]);
@@ -177,12 +177,12 @@ fn test_config_multiple_tools_with_same_name() {
     #[cfg(unix)]
     insta::assert_snapshot!(stderr, @r###"
     Config error: redefinition of table `fix.tools.my-tool` for key `fix.tools.my-tool` at line 6 column 9 in ../config/config0002.toml
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
     #[cfg(windows)]
     insta::assert_snapshot!(stderr, @r###"
     Config error: redefinition of table `fix.tools.my-tool` for key `fix.tools.my-tool` at line 6 column 9 in ..\config\config0002.toml
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
 
     test_env.set_config_path("/dev/null".into());
@@ -258,7 +258,7 @@ fn test_config_tables_all_commands_missing() {
     let stderr = test_env.jj_cmd_failure(&repo_path, &["fix"]);
     insta::assert_snapshot!(stderr, @r###"
     Config error: missing field `command`
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
 
     let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "foo", "-r", "@"]);
@@ -290,7 +290,7 @@ fn test_config_tables_some_commands_missing() {
     let stderr = test_env.jj_cmd_failure(&repo_path, &["fix"]);
     insta::assert_snapshot!(stderr, @r###"
     Config error: missing field `command`
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
 
     let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "foo", "-r", "@"]);
@@ -468,13 +468,13 @@ fn test_fix_parent_commit() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     // Using one file name for all commits adds coverage of some possible bugs.
     std::fs::write(repo_path.join("file"), "parent").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "parent"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "parent"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "child1").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "child1"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "child1"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "-r", "parent"]);
     std::fs::write(repo_path.join("file"), "child2").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "child2"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "child2"]);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["fix", "-s", "parent"]);
     insta::assert_snapshot!(stdout, @"");
@@ -502,13 +502,13 @@ fn test_fix_parent_commit() {
 fn test_fix_sibling_commit() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file"), "parent").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "parent"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "parent"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "child1").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "child1"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "child1"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "-r", "parent"]);
     std::fs::write(repo_path.join("file"), "child2").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "child2"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "child2"]);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["fix", "-s", "child1"]);
     insta::assert_snapshot!(stdout, @"");
@@ -533,22 +533,22 @@ fn test_fix_sibling_commit() {
 fn test_default_revset() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file"), "trunk1").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "trunk1"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "trunk1"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "trunk2").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "trunk2"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "trunk2"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "trunk1"]);
     std::fs::write(repo_path.join("file"), "foo").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "foo"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "foo"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "trunk1"]);
     std::fs::write(repo_path.join("file"), "bar1").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "bar1"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "bar1"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "bar2").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "bar2"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "bar2"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "bar3").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "bar3"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "bar3"]);
     test_env.jj_cmd_ok(&repo_path, &["edit", "bar2"]);
 
     // With no args and no revset configuration, we fix `reachable(@, mutable())`,
@@ -588,10 +588,10 @@ fn test_custom_default_revset() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
 
     std::fs::write(repo_path.join("file"), "foo").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "foo"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "foo"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "bar").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "bar"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "bar"]);
 
     // Check out a different commit so that the schema default `reachable(@,
     // mutable())` would behave differently from our customized default.
@@ -619,10 +619,10 @@ fn test_custom_default_revset() {
 fn test_fix_immutable_commit() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file"), "immutable").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "immutable"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "immutable"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "mutable").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "mutable"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "mutable"]);
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "immutable""#);
 
     let stderr = test_env.jj_cmd_failure(&repo_path, &["fix", "-s", "immutable"]);
@@ -742,16 +742,16 @@ fn test_deduplication() {
     // There are at least two interesting cases: the content is repeated immediately
     // in the child commit, or later in another descendant.
     std::fs::write(repo_path.join("file"), "foo\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "a"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "a"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "bar\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "b"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "b"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "bar\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "c"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "c"]);
     test_env.jj_cmd_ok(&repo_path, &["new"]);
     std::fs::write(repo_path.join("file"), "foo\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "d"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "d"]);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["fix", "-s", "a"]);
     insta::assert_snapshot!(stdout, @"");
@@ -971,11 +971,11 @@ fn test_fix_trivial_merge_commit() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file_a"), "content a").unwrap();
     std::fs::write(repo_path.join("file_c"), "content c").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "a"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "a"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "@-"]);
     std::fs::write(repo_path.join("file_b"), "content b").unwrap();
     std::fs::write(repo_path.join("file_c"), "content c").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "b"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "b"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "a", "b"]);
 
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["fix", "-s", "@"]);
@@ -1005,11 +1005,11 @@ fn test_fix_adding_merge_commit() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file_a"), "content a").unwrap();
     std::fs::write(repo_path.join("file_c"), "content c").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "a"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "a"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "@-"]);
     std::fs::write(repo_path.join("file_b"), "content b").unwrap();
     std::fs::write(repo_path.join("file_c"), "content c").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "b"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "b"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "a", "b"]);
     std::fs::write(repo_path.join("file_a"), "change a").unwrap();
     std::fs::write(repo_path.join("file_b"), "change b").unwrap();
@@ -1045,10 +1045,10 @@ fn test_fix_adding_merge_commit() {
 fn test_fix_both_sides_of_conflict() {
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file"), "content a\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "a"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "a"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "@-"]);
     std::fs::write(repo_path.join("file"), "content b\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "b"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "b"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "a", "b"]);
 
     // The conflicts are not different from the merged parent, so they would not be
@@ -1095,10 +1095,10 @@ fn test_fix_resolve_conflict() {
     // will be resolved.
     let (test_env, repo_path, redact) = init_with_fake_formatter(&["--uppercase"]);
     std::fs::write(repo_path.join("file"), "Content\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "a"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "a"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "@-"]);
     std::fs::write(repo_path.join("file"), "cOnTeNt\n").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "b"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "b"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "a", "b"]);
 
     // The conflicts are not different from the merged parent, so they would not be
@@ -1123,3 +1123,150 @@ fn test_fix_resolve_conflict() {
     CONTENT
     "###);
 }
+
+#[test]
+fn test_all_files() {
+    let test_env = TestEnvironment::default();
+    test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
+    let repo_path = test_env.env_root().join("repo");
+    let formatter_path = assert_cmd::cargo::cargo_bin("fake-formatter");
+    assert!(formatter_path.is_file());
+    let escaped_formatter_path = formatter_path.to_str().unwrap().replace('\\', r"\\");
+
+    // Consider a few cases:
+    // File A:     in patterns,     changed in child
+    // File B:     in patterns, NOT changed in child
+    // File C: NOT in patterns, NOT changed in child
+    // File D: NOT in patterns,     changed in child
+    // Some files will be in subdirectories to make sure we're covering that aspect
+    // of matching.
+    test_env.add_config(&format!(
+        r###"
+        [fix.tools.tool]
+        command = ["{formatter}", "--append", "fixed"]
+        patterns = ["a/a", "b/b"]
+        "###,
+        formatter = escaped_formatter_path.as_str()
+    ));
+
+    std::fs::create_dir(repo_path.join("a")).unwrap();
+    std::fs::create_dir(repo_path.join("b")).unwrap();
+    std::fs::create_dir(repo_path.join("c")).unwrap();
+    std::fs::write(repo_path.join("a/a"), "parent aaa\n").unwrap();
+    std::fs::write(repo_path.join("b/b"), "parent bbb\n").unwrap();
+    std::fs::write(repo_path.join("c/c"), "parent ccc\n").unwrap();
+    std::fs::write(repo_path.join("ddd"), "parent ddd\n").unwrap();
+    let (_stdout, _stderr) = test_env.jj_cmd_ok(&repo_path, &["commit", "-m", "parent"]);
+
+    std::fs::write(repo_path.join("a/a"), "child aaa\n").unwrap();
+    std::fs::write(repo_path.join("ddd"), "child ddd\n").unwrap();
+    let (_stdout, _stderr) = test_env.jj_cmd_ok(&repo_path, &["describe", "-m", "child"]);
+
+    // Specifying files means exactly those files will be fixed in each revision,
+    // although some like file C won't have any tools configured to make changes to
+    // them. Specified but unfixed files are silently skipped, whether they lack
+    // configuration, are ignored, don't exist, aren't normal files, etc.
+    let (stdout, stderr) = test_env.jj_cmd_ok(
+        &repo_path,
+        &[
+            "fix",
+            "--include-unchanged-files",
+            "b/b",
+            "c/c",
+            "does_not.exist",
+        ],
+    );
+    insta::assert_snapshot!(stdout, @"");
+    insta::assert_snapshot!(stderr, @r###"
+    Fixed 2 commits of 2 checked.
+    Working copy now at: rlvkpnrz c098d165 child
+    Parent commit      : qpvuntsm 0bb31627 parent
+    Added 0 files, modified 1 files, removed 0 files
+    "###);
+
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "a/a", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent aaa
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "b/b", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent bbb
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "c/c", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ccc
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "ddd", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ddd
+    "###);
+
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "a/a", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    child aaa
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "b/b", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    parent bbb
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "c/c", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ccc
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "ddd", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    child ddd
+    "###);
+
+    // Not specifying files means all files will be fixed in each revision.
+    let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["fix", "--include-unchanged-files"]);
+    insta::assert_snapshot!(stdout, @"");
+    insta::assert_snapshot!(stderr, @r###"
+    Fixed 2 commits of 2 checked.
+    Working copy now at: rlvkpnrz c5d0aa1d child
+    Parent commit      : qpvuntsm b4d02ca9 parent
+    Added 0 files, modified 2 files, removed 0 files
+    "###);
+
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "a/a", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent aaa
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "b/b", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent bbb
+    fixed
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "c/c", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ccc
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "ddd", "-r", "@-"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ddd
+    "###);
+
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "a/a", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    child aaa
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "b/b", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    parent bbb
+    fixed
+    fixed
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "c/c", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    parent ccc
+    "###);
+    let content = test_env.jj_cmd_success(&repo_path, &["file", "show", "ddd", "-r", "@"]);
+    insta::assert_snapshot!(content, @r###"
+    child ddd
+    "###);
+}
