@@ -23,7 +23,7 @@ fn test_rewrite_immutable_generic() {
     test_env.jj_cmd_ok(&repo_path, &["describe", "-m=a"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "-m=b"]);
     std::fs::write(repo_path.join("file"), "b").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "main"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "main"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "main-", "-m=c"]);
     std::fs::write(repo_path.join("file"), "c").unwrap();
     let stdout = test_env.jj_cmd_success(&repo_path, &["log"]);
@@ -59,12 +59,12 @@ fn test_rewrite_immutable_generic() {
 
     // Error mutating the repo if immutable_heads() uses a ref that can't be
     // resolved
-    test_env.add_config(r#"revset-aliases."immutable_heads()" = "branch_that_does_not_exist""#);
+    test_env.add_config(r#"revset-aliases."immutable_heads()" = "bookmark_that_does_not_exist""#);
     let stderr = test_env.jj_cmd_failure(&repo_path, &["new", "main"]);
     insta::assert_snapshot!(stderr, @r###"
     Config error: Invalid `revset-aliases.immutable_heads()`
-    Caused by: Revision "branch_that_does_not_exist" doesn't exist
-    For help, see https://github.com/martinvonz/jj/blob/main/docs/config.md.
+    Caused by: Revision "bookmark_that_does_not_exist" doesn't exist
+    For help, see https://martinvonz.github.io/jj/latest/config/.
     "###);
 
     // Can use --ignore-immutable to override
@@ -85,7 +85,7 @@ fn test_rewrite_immutable_generic() {
 
     // Mutating the repo works if ref is wrapped in present()
     test_env.add_config(
-        r#"revset-aliases."immutable_heads()" = "present(branch_that_does_not_exist)""#,
+        r#"revset-aliases."immutable_heads()" = "present(bookmark_that_does_not_exist)""#,
     );
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["new", "main"]);
     insta::assert_snapshot!(stdout, @r###"
@@ -107,12 +107,12 @@ fn test_rewrite_immutable_generic() {
 fn test_new_wc_commit_when_wc_immutable() {
     let test_env = TestEnvironment::default();
     test_env.jj_cmd_ok(test_env.env_root(), &["git", "init"]);
-    test_env.jj_cmd_ok(test_env.env_root(), &["branch", "create", "main"]);
+    test_env.jj_cmd_ok(test_env.env_root(), &["bookmark", "create", "main"]);
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "main""#);
     test_env.jj_cmd_ok(test_env.env_root(), &["new", "-m=a"]);
-    let (_, stderr) = test_env.jj_cmd_ok(test_env.env_root(), &["branch", "set", "main"]);
+    let (_, stderr) = test_env.jj_cmd_ok(test_env.env_root(), &["bookmark", "set", "main"]);
     insta::assert_snapshot!(stderr, @r###"
-    Moved 1 branches to kkmpptxz a164195b main | (empty) a
+    Moved 1 bookmarks to kkmpptxz a164195b main | (empty) a
     Warning: The working-copy commit in workspace 'default' became immutable, so a new commit has been created on top of it.
     Working copy now at: zsuskuln ef5fa85b (empty) (no description set)
     Parent commit      : kkmpptxz a164195b main | (empty) a
@@ -123,7 +123,7 @@ fn test_new_wc_commit_when_wc_immutable() {
 fn test_immutable_heads_set_to_working_copy() {
     let test_env = TestEnvironment::default();
     test_env.jj_cmd_ok(test_env.env_root(), &["git", "init"]);
-    test_env.jj_cmd_ok(test_env.env_root(), &["branch", "create", "main"]);
+    test_env.jj_cmd_ok(test_env.env_root(), &["bookmark", "create", "main"]);
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "@""#);
     let (_, stderr) = test_env.jj_cmd_ok(test_env.env_root(), &["new", "-m=a"]);
     insta::assert_snapshot!(stderr, @r###"
@@ -138,15 +138,15 @@ fn test_new_wc_commit_when_wc_immutable_multi_workspace() {
     let test_env = TestEnvironment::default();
     test_env.jj_cmd_ok(test_env.env_root(), &["git", "init", "repo"]);
     let repo_path = test_env.env_root().join("repo");
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "main"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "main"]);
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "main""#);
     test_env.jj_cmd_ok(&repo_path, &["new", "-m=a"]);
     test_env.jj_cmd_ok(&repo_path, &["workspace", "add", "../workspace1"]);
     let workspace1_envroot = test_env.env_root().join("workspace1");
     test_env.jj_cmd_ok(&workspace1_envroot, &["edit", "default@"]);
-    let (_, stderr) = test_env.jj_cmd_ok(&repo_path, &["branch", "set", "main"]);
+    let (_, stderr) = test_env.jj_cmd_ok(&repo_path, &["bookmark", "set", "main"]);
     insta::assert_snapshot!(stderr, @r###"
-    Moved 1 branches to kkmpptxz 7796c4df main | (empty) a
+    Moved 1 bookmarks to kkmpptxz 7796c4df main | (empty) a
     Warning: The working-copy commit in workspace 'default' became immutable, so a new commit has been created on top of it.
     Warning: The working-copy commit in workspace 'workspace1' became immutable, so a new commit has been created on top of it.
     Working copy now at: royxmykx 896465c4 (empty) (no description set)
@@ -180,7 +180,7 @@ fn test_rewrite_immutable_commands() {
     // Create another file to make sure the merge commit isn't empty (to satisfy `jj
     // split`) and still has a conflict (to satisfy `jj resolve`).
     std::fs::write(repo_path.join("file2"), "merged").unwrap();
-    test_env.jj_cmd_ok(&repo_path, &["branch", "create", "main"]);
+    test_env.jj_cmd_ok(&repo_path, &["bookmark", "create", "main"]);
     test_env.jj_cmd_ok(&repo_path, &["new", "description(b)"]);
     test_env.add_config(r#"revset-aliases."immutable_heads()" = "main""#);
     test_env.add_config(r#"revset-aliases."trunk()" = "main""#);
@@ -326,8 +326,10 @@ fn test_rewrite_immutable_commands() {
     "###);
     // unsquash
     let stderr = test_env.jj_cmd_failure(&repo_path, &["unsquash", "-r=main"]);
-    insta::assert_snapshot!(stderr, @r###"
+    insta::assert_snapshot!(stderr, @r#"
+    Warning: `jj unsquash` is deprecated; use `jj diffedit --restore-descendants` or `jj squash` instead
+    Warning: `jj unsquash` will be removed in a future version, and this will be a hard error
     Error: Commit 1d5af877b8bb is immutable
     Hint: Pass `--ignore-immutable` or configure the set of immutable commits via `revset-aliases.immutable_heads()`.
-    "###);
+    "#);
 }
