@@ -18,7 +18,7 @@ use std::path::PathBuf;
 use crate::common::TestEnvironment;
 
 fn get_log_output(test_env: &TestEnvironment, cwd: &Path) -> String {
-    let template = r#"separate(" ", change_id.short(), empty, description, local_branches)"#;
+    let template = r#"separate(" ", change_id.short(), empty, description, local_bookmarks)"#;
     test_env.jj_cmd_success(cwd, &["log", "-T", template])
 }
 
@@ -102,13 +102,14 @@ fn test_split_by_paths() {
     test_env.set_up_fake_editor();
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["split", "-r", "@-", "."]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r###"
+    insta::assert_snapshot!(stderr, @r#"
+    Warning: All changes have been selected, so the second commit will be empty
     Rebased 1 descendant commits
     First part: qpvuntsm 9da0eea0 (no description set)
     Second part: znkkpsqq 5b5714a3 (empty) (no description set)
     Working copy now at: zsuskuln 0c798ee7 (no description set)
     Parent commit      : znkkpsqq 5b5714a3 (empty) (no description set)
-    "###);
+    "#);
 
     insta::assert_snapshot!(get_log_output(&test_env, &repo_path), @r###"
     @  zsuskulnrvyr false
@@ -129,14 +130,14 @@ fn test_split_by_paths() {
     test_env.set_up_fake_editor();
     let (stdout, stderr) = test_env.jj_cmd_ok(&repo_path, &["split", "-r", "@-", "nonexistent"]);
     insta::assert_snapshot!(stdout, @"");
-    insta::assert_snapshot!(stderr, @r###"
-    Warning: The given paths do not match any file: nonexistent
+    insta::assert_snapshot!(stderr, @r#"
+    Warning: No changes have been selected, so the first commit will be empty
     Rebased 1 descendant commits
     First part: qpvuntsm bd42f95a (empty) (no description set)
     Second part: lylxulpl ed55c86b (no description set)
     Working copy now at: zsuskuln 1e1ed741 (no description set)
     Parent commit      : lylxulpl ed55c86b (no description set)
-    "###);
+    "#);
 
     insta::assert_snapshot!(get_log_output(&test_env, &repo_path), @r###"
     @  zsuskulnrvyr false
@@ -220,9 +221,9 @@ fn test_split_with_default_description() {
     std::fs::write(workspace_path.join("file1"), "foo\n").unwrap();
     std::fs::write(workspace_path.join("file2"), "bar\n").unwrap();
 
-    // Create a branch pointing to the commit. It will be moved to the second
+    // Create a bookmark pointing to the commit. It will be moved to the second
     // commit after the split.
-    test_env.jj_cmd_ok(&workspace_path, &["branch", "create", "test_branch"]);
+    test_env.jj_cmd_ok(&workspace_path, &["bookmark", "create", "test_bookmark"]);
 
     let edit_script = test_env.set_up_fake_editor();
     std::fs::write(
@@ -234,8 +235,8 @@ fn test_split_with_default_description() {
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
     First part: qpvuntsm 48018df6 TESTED=TODO
-    Second part: kkmpptxz 350b4c13 test_branch | (no description set)
-    Working copy now at: kkmpptxz 350b4c13 test_branch | (no description set)
+    Second part: kkmpptxz 350b4c13 test_bookmark | (no description set)
+    Working copy now at: kkmpptxz 350b4c13 test_bookmark | (no description set)
     Parent commit      : qpvuntsm 48018df6 TESTED=TODO
     "###);
 
@@ -257,7 +258,7 @@ fn test_split_with_default_description() {
     "###);
     assert!(!test_env.env_root().join("editor2").exists());
     insta::assert_snapshot!(get_log_output(&test_env, &workspace_path), @r###"
-    @  kkmpptxzrspx false test_branch
+    @  kkmpptxzrspx false test_bookmark
     ○  qpvuntsmwlqt false TESTED=TODO
     ◆  zzzzzzzzzzzz true
     "###);
@@ -328,11 +329,11 @@ fn test_split_siblings_no_descendants() {
     std::fs::write(workspace_path.join("file1"), "foo\n").unwrap();
     std::fs::write(workspace_path.join("file2"), "bar\n").unwrap();
 
-    // Create a branch pointing to the commit. It will be moved to the second
+    // Create a bookmark pointing to the commit. It will be moved to the second
     // commit after the split.
-    test_env.jj_cmd_ok(&workspace_path, &["branch", "create", "test_branch"]);
+    test_env.jj_cmd_ok(&workspace_path, &["bookmark", "create", "test_bookmark"]);
     insta::assert_snapshot!(get_log_output(&test_env, &workspace_path), @r###"
-    @  qpvuntsmwlqt false test_branch
+    @  qpvuntsmwlqt false test_bookmark
     ◆  zzzzzzzzzzzz true
     "###);
 
@@ -346,13 +347,13 @@ fn test_split_siblings_no_descendants() {
     insta::assert_snapshot!(stdout, @"");
     insta::assert_snapshot!(stderr, @r###"
     First part: qpvuntsm 0dced07a TESTED=TODO
-    Second part: zsuskuln 0473f014 test_branch | (no description set)
-    Working copy now at: zsuskuln 0473f014 test_branch | (no description set)
+    Second part: zsuskuln 0473f014 test_bookmark | (no description set)
+    Working copy now at: zsuskuln 0473f014 test_bookmark | (no description set)
     Parent commit      : zzzzzzzz 00000000 (empty) (no description set)
     Added 0 files, modified 0 files, removed 1 files
     "###);
     insta::assert_snapshot!(get_log_output(&test_env, &workspace_path), @r###"
-    @  zsuskulnrvyr false test_branch
+    @  zsuskulnrvyr false test_bookmark
     │ ○  qpvuntsmwlqt false TESTED=TODO
     ├─╯
     ◆  zzzzzzzzzzzz true
@@ -576,15 +577,14 @@ fn test_split_interactive() {
     let (stdout, stderr) = test_env.jj_cmd_ok(&workspace_path, &["split"]);
 
     insta::assert_snapshot!(
-        std::fs::read_to_string(test_env.env_root().join("instrs")).unwrap(), @r###"
+        std::fs::read_to_string(test_env.env_root().join("instrs")).unwrap(), @r#"
     You are splitting a commit into two: qpvuntsm 44af2155 (no description set)
 
     The diff initially shows the changes in the commit you're splitting.
 
     Adjust the right side until it shows the contents you want for the first commit.
-    The remainder will be in the second commit. If you don't make any changes, then
-    the operation will be aborted.
-    "###);
+    The remainder will be in the second commit.
+    "#);
 
     insta::assert_snapshot!(
         std::fs::read_to_string(test_env.env_root().join("editor")).unwrap(), @r###"
