@@ -14,7 +14,7 @@ new_tmp_dir
     echo "third" > file
     jj branch create third
     jj commit -m 'third'
-) >/dev/null
+) >/dev/null 2>&1
 
 comment "We are in a repo with three commits, all
 editing the same line:"
@@ -25,7 +25,7 @@ run_command "jj diff -r second"
 run_command "jj diff -r third"
 
 comment "Let's reorder the second and third commits:"
-run_command "jj rebase -s third -d first"
+run_command_output_redacted "jj rebase -s third -d first"
 run_command "jj rebase -s second -d third"
 run_command "jj log"
 comment "The commit labeled \"third\" has a conflict, as expected. What's more
@@ -33,13 +33,13 @@ interesting is that the top commit has no conflict! That's because it
 has the changes from all three commits applied to it.
 
 Let's verify that by looking at its contents:"
-run_command "jj co second"
+run_command "jj new second"
 run_command "cat file"
 
 comment "Let's now instead make \"second\" and \"third\"
 sibling and merge them:"
 run_command "jj rebase -s second -d first"
-run_command "jj merge second third -m merged"
+run_command "jj new second third -m merged"
 run_command "jj log"
 comment "Again, because the merge commit has the
 changes from all three commits, it has no
