@@ -25,6 +25,7 @@ use futures::Stream;
 use futures::StreamExt;
 use futures::TryStreamExt;
 use itertools::Itertools;
+use pollster::FutureExt;
 use regex::bytes::Regex;
 use regex::bytes::RegexBuilder;
 
@@ -455,7 +456,7 @@ fn parse_conflict_hunk(input: &[u8]) -> Merge<BString> {
                     removes.last_mut().unwrap().extend_from_slice(rest);
                     adds.last_mut().unwrap().extend_from_slice(rest);
                 } else {
-                    // Doesn't look like a conflict
+                    // Doesn't look like a valid conflict
                     return Merge::resolved(BString::new(vec![]));
                 }
             }
@@ -466,13 +467,18 @@ fn parse_conflict_hunk(input: &[u8]) -> Merge<BString> {
                 adds.last_mut().unwrap().extend_from_slice(line);
             }
             State::Unknown => {
-                // Doesn't look like a conflict
+                // Doesn't look like a valid conflict
                 return Merge::resolved(BString::new(vec![]));
             }
         }
     }
 
-    Merge::from_removes_adds(removes, adds)
+    if adds.len() == removes.len() + 1 {
+        Merge::from_removes_adds(removes, adds)
+    } else {
+        // Doesn't look like a valid conflict
+        Merge::resolved(BString::new(vec![]))
+    }
 }
 
 /// Parses conflict markers in `content` and returns an updated version of
@@ -513,7 +519,7 @@ pub async fn update_from_content(
             };
         };
         // Either there are no markers or they don't have the expected arity
-        let file_id = store.write_file(path, &mut &content[..])?;
+        let file_id = store.write_file(path, &mut &content[..]).await?;
         return Ok(Merge::normal(file_id));
     };
 
@@ -535,17 +541,18 @@ pub async fn update_from_content(
     if zip(contents.iter(), used_file_ids.iter())
         .any(|(content, file_id)| file_id.is_none() && !content.is_empty())
     {
-        let file_id = store.write_file(path, &mut &content[..])?;
+        let file_id = store.write_file(path, &mut &content[..]).await?;
         return Ok(Merge::normal(file_id));
     }
 
     // Now write the new files contents we found by parsing the file with conflict
     // markers.
+    // TODO: Write these concurrently
     let new_file_ids: Vec<Option<FileId>> = zip(contents.iter(), used_file_ids.iter())
         .map(|(content, file_id)| -> BackendResult<Option<FileId>> {
             match file_id {
                 Some(_) => {
-                    let file_id = store.write_file(path, &mut content.as_slice())?;
+                    let file_id = store.write_file(path, &mut content.as_slice()).block_on()?;
                     Ok(Some(file_id))
                 }
                 None => {
