@@ -1170,9 +1170,10 @@ fn has_diff_from_parent(
     // TODO: handle copy tracking
     let mut tree_diff = from_tree.diff_stream(&to_tree, matcher);
     async {
+        // TODO: Resolve values concurrently
         while let Some(entry) = tree_diff.next().await {
             let (from_value, to_value) = entry.values?;
-            let from_value = resolve_file_values(store, &entry.path, from_value)?;
+            let from_value = resolve_file_values(store, &entry.path, from_value).await?;
             if from_value == to_value {
                 continue;
             }
@@ -1197,9 +1198,10 @@ fn matches_diff_from_parent(
     // TODO: handle copy tracking
     let mut tree_diff = from_tree.diff_stream(&to_tree, files_matcher);
     async {
+        // TODO: Resolve values concurrently
         while let Some(entry) = tree_diff.next().await {
             let (left_value, right_value) = entry.values?;
-            let left_value = resolve_file_values(store, &entry.path, left_value)?;
+            let left_value = resolve_file_values(store, &entry.path, left_value).await?;
             if left_value == right_value {
                 continue;
             }
