@@ -14,7 +14,8 @@
 
 #![allow(missing_docs)]
 
-use std::path::{Path, PathBuf};
+use std::path::Path;
+use std::path::PathBuf;
 
 use crate::submodule_store::SubmoduleStore;
 
@@ -45,6 +46,6 @@ impl DefaultSubmoduleStore {
 
 impl SubmoduleStore for DefaultSubmoduleStore {
     fn name(&self) -> &str {
-        DefaultSubmoduleStore::name()
+        Self::name()
     }
 }
