@@ -15,19 +15,28 @@
 #![allow(missing_docs)]
 
 use std::cmp::Ordering;
-use std::fmt::{Debug, Error, Formatter};
-use std::hash::{Hash, Hasher};
+use std::fmt::Debug;
+use std::fmt::Error;
+use std::fmt::Formatter;
+use std::hash::Hash;
+use std::hash::Hasher;
 use std::sync::Arc;
 
 use crate::op_store;
-use crate::op_store::{OpStore, OpStoreResult, OperationId, ViewId};
+use crate::op_store::OpStore;
+use crate::op_store::OpStoreResult;
+use crate::op_store::OperationId;
+use crate::op_store::OperationMetadata;
+use crate::op_store::ViewId;
 use crate::view::View;
 
+/// A wrapper around [`op_store::Operation`] that defines additional methods and
+/// stores a pointer to the `OpStore` the operation belongs to.
 #[derive(Clone)]
 pub struct Operation {
     op_store: Arc<dyn OpStore>,
     id: OperationId,
-    data: op_store::Operation,
+    data: Arc<op_store::Operation>, // allow cheap clone
 }
 
 impl Debug for Operation {
@@ -63,8 +72,16 @@ impl Hash for Operation {
 }
 
 impl Operation {
-    pub fn new(op_store: Arc<dyn OpStore>, id: OperationId, data: op_store::Operation) -> Self {
-        Operation { op_store, id, data }
+    pub fn new(
+        op_store: Arc<dyn OpStore>,
+        id: OperationId,
+        data: impl Into<Arc<op_store::Operation>>,
+    ) -> Self {
+        Operation {
+            op_store,
+            id,
+            data: data.into(),
+        }
     }
 
     pub fn op_store(&self) -> Arc<dyn OpStore> {
@@ -96,6 +113,10 @@ impl Operation {
         Ok(View::new(data))
     }
 
+    pub fn metadata(&self) -> &OperationMetadata {
+        &self.data.metadata
+    }
+
     pub fn store_operation(&self) -> &op_store::Operation {
         &self.data
     }
