@@ -726,7 +726,8 @@ fn test_parse_conflict_multi_way() {
 }
 
 #[test]
-fn test_parse_conflict_different_wrong_arity() {
+fn test_parse_conflict_wrong_arity() {
+    // Valid conflict marker but it has fewer sides than the caller expected
     assert_eq!(
         parse_conflict(
             indoc! {b"
@@ -748,6 +749,27 @@ fn test_parse_conflict_different_wrong_arity() {
     )
 }
 
+#[test]
+fn test_parse_conflict_malformed_missing_removes() {
+    // Right number of adds but missing removes
+    assert_eq!(
+        parse_conflict(
+            indoc! {b"
+            line 1
+            <<<<<<<
+            +++++++
+            left
+            +++++++
+            right
+            >>>>>>>
+            line 5
+            "},
+            2
+        ),
+        None
+    )
+}
+
 #[test]
 fn test_parse_conflict_malformed_marker() {
     // The conflict marker is missing `%%%%%%%`
