@@ -96,7 +96,7 @@ fn test_index_commits_standard_cases() {
 
     let root_commit_id = repo.store().root_commit_id();
     let mut tx = repo.start_transaction(&settings);
-    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.mut_repo());
+    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.repo_mut());
     let commit_a = graph_builder.initial_commit();
     let commit_b = graph_builder.commit_with_parents(&[&commit_a]);
     let commit_c = graph_builder.commit_with_parents(&[&commit_a]);
@@ -153,7 +153,7 @@ fn test_index_commits_criss_cross() {
     // keeping track of visited nodes, it would be 2^50 visits, so if this test
     // finishes in reasonable time, we know that we don't do a naive traversal.
     let mut tx = repo.start_transaction(&settings);
-    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.mut_repo());
+    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.repo_mut());
     let mut left_commits = vec![graph_builder.initial_commit()];
     let mut right_commits = vec![graph_builder.initial_commit()];
     for gen in 1..num_generations {
@@ -307,14 +307,14 @@ fn test_index_commits_previous_operations() {
     // o root
 
     let mut tx = repo.start_transaction(&settings);
-    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.mut_repo());
+    let mut graph_builder = CommitGraphBuilder::new(&settings, tx.repo_mut());
     let commit_a = graph_builder.initial_commit();
     let commit_b = graph_builder.commit_with_parents(&[&commit_a]);
     let commit_c = graph_builder.commit_with_parents(&[&commit_b]);
     let repo = tx.commit("test");
 
     let mut tx = repo.start_transaction(&settings);
-    tx.mut_repo().remove_head(commit_c.id());
+    tx.repo_mut().remove_head(commit_c.id());
     let repo = tx.commit("test");
 
     // Delete index from disk
@@ -322,7 +322,7 @@ fn test_index_commits_previous_operations() {
         repo.index_store().as_any().downcast_ref().unwrap();
     default_index_store.reinit().unwrap();
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     let index = as_readonly_composite(&repo);
     // There should be the root commit, plus 3 more
     assert_eq!(index.num_commits(), 1 + 3);
@@ -344,19 +344,19 @@ fn test_index_commits_hidden_but_referenced() {
     let test_repo = TestRepo::init();
     let repo = &test_repo.repo;
 
-    // Remote branches are usually visible at a certain point in operation
+    // Remote bookmarks are usually visible at a certain point in operation
     // history, but that's not guaranteed if old operations have been discarded.
-    // This can also happen if imported remote branches get immediately
-    // abandoned because the other branch has moved.
+    // This can also happen if imported remote bookmarks get immediately
+    // abandoned because the other bookmark has moved.
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = write_random_commit(tx.mut_repo(), &settings);
-    let commit_b = write_random_commit(tx.mut_repo(), &settings);
-    let commit_c = write_random_commit(tx.mut_repo(), &settings);
-    tx.mut_repo().remove_head(commit_a.id());
-    tx.mut_repo().remove_head(commit_b.id());
-    tx.mut_repo().remove_head(commit_c.id());
-    tx.mut_repo().set_remote_branch(
-        "branch",
+    let commit_a = write_random_commit(tx.repo_mut(), &settings);
+    let commit_b = write_random_commit(tx.repo_mut(), &settings);
+    let commit_c = write_random_commit(tx.repo_mut(), &settings);
+    tx.repo_mut().remove_head(commit_a.id());
+    tx.repo_mut().remove_head(commit_b.id());
+    tx.repo_mut().remove_head(commit_c.id());
+    tx.repo_mut().set_remote_bookmark(
+        "bookmark",
         "origin",
         RemoteRef {
             target: RefTarget::from_legacy_form(
@@ -378,7 +378,7 @@ fn test_index_commits_hidden_but_referenced() {
         repo.index_store().as_any().downcast_ref().unwrap();
     default_index_store.reinit().unwrap();
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     // All commits should be reindexed
     assert!(repo.index().has_id(commit_a.id()));
     assert!(repo.index().has_id(commit_b.id()));
@@ -402,7 +402,7 @@ fn test_index_commits_incremental() {
 
     let root_commit = repo.store().root_commit();
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = child_commit(tx.mut_repo(), &settings, &root_commit)
+    let commit_a = child_commit(tx.repo_mut(), &settings, &root_commit)
         .write()
         .unwrap();
     let repo = tx.commit("test");
@@ -412,15 +412,15 @@ fn test_index_commits_incremental() {
     assert_eq!(index.num_commits(), 1 + 1);
 
     let mut tx = repo.start_transaction(&settings);
-    let commit_b = child_commit(tx.mut_repo(), &settings, &commit_a)
+    let commit_b = child_commit(tx.repo_mut(), &settings, &commit_a)
         .write()
         .unwrap();
-    let commit_c = child_commit(tx.mut_repo(), &settings, &commit_b)
+    let commit_c = child_commit(tx.repo_mut(), &settings, &commit_b)
         .write()
         .unwrap();
     tx.commit("test");
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     let index = as_readonly_composite(&repo);
     // There should be the root commit, plus 3 more
     assert_eq!(index.num_commits(), 1 + 3);
@@ -453,7 +453,7 @@ fn test_index_commits_incremental_empty_transaction() {
 
     let root_commit = repo.store().root_commit();
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = child_commit(tx.mut_repo(), &settings, &root_commit)
+    let commit_a = child_commit(tx.repo_mut(), &settings, &root_commit)
         .write()
         .unwrap();
     let repo = tx.commit("test");
@@ -464,7 +464,7 @@ fn test_index_commits_incremental_empty_transaction() {
 
     repo.start_transaction(&settings).commit("test");
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     let index = as_readonly_composite(&repo);
     // There should be the root commit, plus 1 more
     assert_eq!(index.num_commits(), 1 + 1);
@@ -495,7 +495,7 @@ fn test_index_commits_incremental_already_indexed() {
 
     let root_commit = repo.store().root_commit();
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = child_commit(tx.mut_repo(), &settings, &root_commit)
+    let commit_a = child_commit(tx.repo_mut(), &settings, &root_commit)
         .write()
         .unwrap();
     let repo = tx.commit("test");
@@ -503,7 +503,7 @@ fn test_index_commits_incremental_already_indexed() {
     assert!(repo.index().has_id(commit_a.id()));
     assert_eq!(as_readonly_composite(&repo).num_commits(), 1 + 1);
     let mut tx = repo.start_transaction(&settings);
-    let mut_repo = tx.mut_repo();
+    let mut_repo = tx.repo_mut();
     mut_repo.add_head(&commit_a).unwrap();
     assert_eq!(as_mutable_composite(mut_repo).num_commits(), 1 + 1);
 }
@@ -516,7 +516,7 @@ fn create_n_commits(
 ) -> Arc<ReadonlyRepo> {
     let mut tx = repo.start_transaction(settings);
     for _ in 0..num_commits {
-        write_random_commit(tx.mut_repo(), settings);
+        write_random_commit(tx.repo_mut(), settings);
     }
     tx.commit("test")
 }
@@ -616,16 +616,16 @@ fn test_reindex_no_segments_dir() {
     let repo = &test_repo.repo;
 
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = write_random_commit(tx.mut_repo(), &settings);
+    let commit_a = write_random_commit(tx.repo_mut(), &settings);
     let repo = tx.commit("test");
     assert!(repo.index().has_id(commit_a.id()));
 
     // jj <= 0.14 doesn't have "segments" directory
-    let segments_dir = repo.repo_path().join("index").join("segments");
+    let segments_dir = test_repo.repo_path().join("index").join("segments");
     assert!(segments_dir.is_dir());
     fs::remove_dir_all(&segments_dir).unwrap();
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     assert!(repo.index().has_id(commit_a.id()));
 }
 
@@ -636,12 +636,12 @@ fn test_reindex_corrupt_segment_files() {
     let repo = &test_repo.repo;
 
     let mut tx = repo.start_transaction(&settings);
-    let commit_a = write_random_commit(tx.mut_repo(), &settings);
+    let commit_a = write_random_commit(tx.repo_mut(), &settings);
     let repo = tx.commit("test");
     assert!(repo.index().has_id(commit_a.id()));
 
     // Corrupt the index files
-    let segments_dir = repo.repo_path().join("index").join("segments");
+    let segments_dir = test_repo.repo_path().join("index").join("segments");
     for entry in segments_dir.read_dir().unwrap() {
         let entry = entry.unwrap();
         // u32: file format version
@@ -653,7 +653,7 @@ fn test_reindex_corrupt_segment_files() {
         fs::write(entry.path(), b"\0".repeat(24)).unwrap()
     }
 
-    let repo = load_repo_at_head(&settings, repo.repo_path());
+    let repo = load_repo_at_head(&settings, test_repo.repo_path());
     assert!(repo.index().has_id(commit_a.id()));
 }
 
@@ -674,17 +674,17 @@ fn test_reindex_from_merged_operation() {
     let mut txs = Vec::new();
     for _ in 0..2 {
         let mut tx = repo.start_transaction(&settings);
-        let commit = write_random_commit(tx.mut_repo(), &settings);
+        let commit = write_random_commit(tx.repo_mut(), &settings);
         let repo = tx.commit("test");
         let mut tx = repo.start_transaction(&settings);
-        tx.mut_repo().remove_head(commit.id());
+        tx.repo_mut().remove_head(commit.id());
         txs.push(tx);
     }
     let repo = commit_transactions(&settings, txs);
     let mut op_ids_to_delete = Vec::new();
     op_ids_to_delete.push(repo.op_id());
     let mut tx = repo.start_transaction(&settings);
-    write_random_commit(tx.mut_repo(), &settings);
+    write_random_commit(tx.repo_mut(), &settings);
     let repo = tx.commit("test");
     op_ids_to_delete.push(repo.op_id());
     let operation_to_reload = repo.operation();
@@ -693,7 +693,7 @@ fn test_reindex_from_merged_operation() {
     let index = as_readonly_composite(&repo);
     assert_eq!(index.num_commits(), 4);
 
-    let index_operations_dir = repo.repo_path().join("index").join("operations");
+    let index_operations_dir = test_repo.repo_path().join("index").join("operations");
     for &op_id in &op_ids_to_delete {
         fs::remove_file(index_operations_dir.join(op_id.hex())).unwrap();
     }
@@ -713,18 +713,18 @@ fn test_reindex_missing_commit() {
     let repo = &test_repo.repo;
 
     let mut tx = repo.start_transaction(&settings);
-    let missing_commit = write_random_commit(tx.mut_repo(), &settings);
+    let missing_commit = write_random_commit(tx.repo_mut(), &settings);
     let repo = tx.commit("test");
     let bad_op_id = repo.op_id();
 
     let mut tx = repo.start_transaction(&settings);
-    tx.mut_repo().remove_head(missing_commit.id());
+    tx.repo_mut().remove_head(missing_commit.id());
     let repo = tx.commit("test");
 
     // Remove historical head commit to simulate bad GC.
     let test_backend: &TestBackend = repo.store().backend_impl().downcast_ref().unwrap();
     test_backend.remove_commit_unchecked(missing_commit.id());
-    let repo = load_repo_at_head(&settings, repo.repo_path()); // discard cache
+    let repo = load_repo_at_head(&settings, test_repo.repo_path()); // discard cache
     assert!(repo.store().get_commit(missing_commit.id()).is_err());
 
     // Reindexing error should include the operation id where the commit
@@ -745,7 +745,7 @@ fn test_index_store_type() {
     let repo = &test_repo.repo;
 
     assert_eq!(as_readonly_composite(repo).num_commits(), 1);
-    let index_store_type_path = repo.repo_path().join("index").join("type");
+    let index_store_type_path = test_repo.repo_path().join("index").join("type");
     assert_eq!(
         std::fs::read_to_string(index_store_type_path).unwrap(),
         "default"
@@ -764,7 +764,7 @@ fn test_change_id_index() {
     let mut commit_number = 0;
     let mut commit_with_change_id = |change_id| {
         commit_number += 1;
-        tx.mut_repo()
+        tx.repo_mut()
             .new_commit(
                 &settings,
                 vec![root_commit.id().clone()],
