@@ -54,6 +54,7 @@ fn test_init_additional_workspace() {
     let (ws2, repo) = Workspace::init_workspace_with_existing_repo(
         &settings,
         &ws2_root,
+        test_workspace.repo_path(),
         &test_workspace.repo,
         &*default_working_copy_factory(),
         ws2_id.clone(),
@@ -94,7 +95,7 @@ fn test_init_additional_workspace() {
 fn test_sendable() {
     let settings = testutils::user_settings();
     let test_workspace = TestWorkspace::init(&settings);
-    let root = test_workspace.workspace.workspace_root().clone();
+    let root = test_workspace.workspace.workspace_root().to_owned();
 
     thread::spawn(move || {
         let shared_workspace = test_workspace.workspace;
